@@ -27,6 +27,7 @@ mysqld="/usr/sbin/mysqld --no-defaults --user=$user --bind-address=127.0.0.1 --p
 # Main code #
 
 if [ "$action" = "stop" ]; then
+    echo "Stopping MySQL..."
     if $mysqladmin ping 2>/dev/null; then
         pid=$(lsof -Fp -n -i TCP:$port -s TCP:LISTEN | sed -n -s 's/^p//p')
         if [ -z "$pid" ]; then
@@ -58,6 +59,7 @@ mkdir -p $datadir
 chmod go-rx $datadir
 chown $user: $datadir
 
+echo "Installing a test MySQL instance in $datadir..."
 mysql_install_db --no-defaults --user=$user --datadir=$datadir --rpm --force
 
 tmpf=$(mktemp)
@@ -73,12 +75,12 @@ $mysqld --bootstrap --skip-grant-tables < "$tmpf"
 
 unlink "$tmpf"
 
-# Start the daemon
+echo "Starting the daemon..."
 $mysqld &
 
 pid=$!
 
-# Wait for the server to be actually available
+echo "Waiting for the server to be actually available..."
 c=0;
 while ! nc -z 127.0.0.1 $port; do
     c=$(($c+1));
@@ -94,12 +96,12 @@ while ! nc -z 127.0.0.1 $port; do
     fi
 done
 
-# Check if the server is running
+echo "Checking if the server is running..."
 $mysqladmin status
 
 for db in moneta moneta_activerecord1 moneta_activerecord2; do
-    # Drop the database if it exists
+    echo "Dropping the database $db if it exists..."
     $mysqladmin --force --silent drop $db || true
-    # Create new empty databases
+    echo "Creating new empty database $db..."
     $mysqladmin create $db
 done
